<?php

namespace Drupal\simple_media_bulk_upload;

use Drupal\Core\Form\FormStateInterface;

/**
 * Form helper for handling bulk upload of media items.
 */
class BulkUploadFormHelper {

  /**
   * Add redirect to next entity in the queue for bulk creation.
   *
   * @param array $form
   *   The form array.
   * @param \Drupal\Core\Form\FormStateInterface $formState
   *   The form state object for the media form.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public static function processSubmissionRedirectForBulkUpload(array &$form, FormStateInterface $formState): void {
    $query = \Drupal::request()->query;
    if ($query->has('bulk_create')) {
      // If there are more entities to create, redirect to the edit form for the
      // next one in line.
      $queue = $query->get('bulk_create', []);

      if (is_array($queue)) {
        $remaining = count($queue);
        \Drupal::messenger()->addMessage(\Drupal::translation()->formatPlural(
          $remaining,
          'Editing last remaining item from the bulk upload.',
          '@count remaining items to edit from the bulk upload.',
          ['@count' => $remaining]
        ));

        $id = array_shift($queue);
        $redirect = \Drupal::entityTypeManager()
          ->getStorage('media')
          ->load($id)
          ->toUrl('edit-form', [
            'query' => [
              'bulk_create' => $queue ?: TRUE,
            ],
          ]);
        $formState->setRedirectUrl($redirect);
      }
      else {
        \Drupal::messenger()->addMessage(t('All items from the bulk upload have been updated.'));
      }
    }
  }

}
